# Drug Response Prediction Model Suite

This project is a collaboration of the Technical University of Munich (TUM, Germany) 
and the Freie Universität Berlin (FU, Germany) to develop a suite 
for evaluating drug response prediction machine learning models in a fair setting.

## Installation (Change later)

Create the correct environment:
```bash
conda env create -f models/SimpleNeuralNetwork/env.yml
pip install .
```

## Contact
Main developers: 

- [Judith Bernett](mailto:judith.bernett@tum.de), TUM, TUM School of Life Sciences, Data Science in Systems Biology
- [Pascal Iversen](mailto:Pascal.Iversen@hpi.de), FU, Hasso Plattner Institute
- [Mario Picciani](mailto:mario.picciani@tum.de), TUM, TUM School of Life Sciences, Computational Mass Spectrometry
